@README.md
@Python.md
@Makefile

Always run `make dev`, `make test` after you've made changes. 
Before you commit and push, make sure you run `make test-coverage` and `make type-coverage` to ensure 100% coverage. 
When you finish a piece of work and all checks passing, make sure you commit and push.